@@ -1204,6 +1204,7 @@ def fit_pulsed_frac(en, den, pf, dpf, stem=None, degree_pol=4, n_gauss=0, center
         
         plt.savefig(stem + 'fit_results.pdf')
 
+    #Is it of any use maybe to remove?
     if print_results:
         datafile = open(stem + 'model_components_fit.dat', 'w')
         datafile.write('# fit results \n')
@@ -1345,6 +1346,10 @@ def explore_fit_mcmc(model_fitted, pars=[], hm_steps=7000, hm_walkers=2000, hm_j
 
     o_f_emcee.close()
 
+    from astropy.table import Table
+    flatchain= Table.from_pandas(explore.flatchain)
+    flatchain.write(stem+'.fits')
+
     return explore, emcee_plot
 
 
